==> blueprint-component-mapper-3.6.0.tgz: package/esm/form-group/form-group.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { FormGroup } from "@blueprintjs/core/lib/esm/components/forms/formGroup.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import BlueprintContext from '../blueprint-context/blueprint-context';
export var FormGroupInternal = function FormGroupInternal(_ref) {
  var meta = _ref.meta,
      validateOnMount = _ref.validateOnMount,
      helperText = _ref.helperText,
      description = _ref.description,
      hideLabel = _ref.hideLabel,
      isReadOnly = _ref.isReadOnly,
      label = _ref.label,
      input = _ref.input,
      isDisabled = _ref.isDisabled,
      isRequired = _ref.isRequired,
      FormGroupProps = _ref.FormGroupProps,
      Component = _ref.Component,
      rest = _objectWithoutProperties(_ref, ["meta", "validateOnMount", "helperText", "description", "hideLabel", "isReadOnly", "label", "input", "isDisabled", "isRequired", "FormGroupProps", "Component"]);

  var _useContext = useContext(BlueprintContext),
      required = _useContext.required;

  var error = meta.error,
      touched = meta.touched,
      warning = meta.warning,
      submitError = meta.submitError;
  var showError = (validateOnMount || touched) && (error || submitError);
  var showWarning = (validateOnMount || touched) && warning;
  var text = showError || showWarning || helperText || description;
  var intent = showError && {
    intent: Intent.DANGER
  } || showWarning && {
    intent: Intent.WARNING
  };
  var labelInfo = !hideLabel && isRequired && {
    labelInfo: required
  };
  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    helperText: text,
    label: !hideLabel && label,
    labelFor: input.name
  }, labelInfo, FormGroupProps, intent), /*#__PURE__*/React.createElement(Component, _extends({
    providerRequired: required,
    disabled: isDisabled || isReadOnly
  }, rest, {
    label: label,
    isRequired: isRequired,
    input: input
  }, intent)));
};
FormGroupInternal.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  Component: PropTypes.any,
  helperText: PropTypes.node,
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  description: PropTypes.node,
  FormGroupProps: PropTypes.object,
  hideLabel: PropTypes.bool,
  meta: PropTypes.object,
  input: PropTypes.object
};

var FormGroupWrapper = function FormGroupWrapper(props) {
  var rest = useFieldApi(props);
  return /*#__PURE__*/React.createElement(FormGroupInternal, rest);
};

export default FormGroupWrapper;

==> blueprint-component-mapper-3.15.3.tgz: package/esm/form-group/form-group.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["meta", "validateOnMount", "helperText", "description", "hideLabel", "isReadOnly", "label", "input", "isDisabled", "isRequired", "FormGroupProps", "Component"];
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { FormGroup } from "@blueprintjs/core/lib/esm/components/forms/formGroup.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import BlueprintContext from '../blueprint-context/blueprint-context';
export var FormGroupInternal = function FormGroupInternal(_ref) {
  var meta = _ref.meta,
      validateOnMount = _ref.validateOnMount,
      helperText = _ref.helperText,
      description = _ref.description,
      hideLabel = _ref.hideLabel,
      isReadOnly = _ref.isReadOnly,
      label = _ref.label,
      input = _ref.input,
      isDisabled = _ref.isDisabled,
      isRequired = _ref.isRequired,
      FormGroupProps = _ref.FormGroupProps,
      Component = _ref.Component,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(BlueprintContext),
      required = _useContext.required;

  var error = meta.error,
      touched = meta.touched,
      warning = meta.warning,
      submitError = meta.submitError;
  var showError = (validateOnMount || touched) && (error || submitError);
  var showWarning = (validateOnMount || touched) && warning;
  var text = showError || showWarning || helperText || description;
  var intent = showError && {
    intent: Intent.DANGER
  } || showWarning && {
    intent: Intent.WARNING
  };
  var labelInfo = !hideLabel && isRequired && {
    labelInfo: required
  };
  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    helperText: text,
    label: !hideLabel && label,
    labelFor: input.name
  }, labelInfo, FormGroupProps, intent), /*#__PURE__*/React.createElement(Component, _extends({
    providerRequired: required,
    disabled: isDisabled || isReadOnly
  }, rest, {
    label: label,
    isRequired: isRequired,
    input: input
  }, intent)));
};
FormGroupInternal.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  Component: PropTypes.any,
  helperText: PropTypes.node,
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  description: PropTypes.node,
  FormGroupProps: PropTypes.object,
  hideLabel: PropTypes.bool,
  meta: PropTypes.object,
  input: PropTypes.object
};

var FormGroupWrapper = function FormGroupWrapper(props) {
  var rest = useFieldApi(props);
  return /*#__PURE__*/React.createElement(FormGroupInternal, rest);
};

export default FormGroupWrapper;
